summaryrefslogtreecommitdiff
path: root/os/bs2000
diff options
context:
space:
mode:
authorDoug MacEachern <dougm@apache.org>2000-08-02 05:27:38 +0000
committerDoug MacEachern <dougm@apache.org>2000-08-02 05:27:38 +0000
commit059d8dd2122f0a3948c2c09549159f0931a6f236 (patch)
tree8a2937938ed4eec31f918c6c8401ce07012cd37a /os/bs2000
parent3ae78ff3833de9187e9fc0eb6aab69a8b8162c5a (diff)
downloadhttpd-059d8dd2122f0a3948c2c09549159f0931a6f236.tar.gz
prefix libapr functions and types with apr_
git-svn-id: https://svn.apache.org/repos/asf/httpd/httpd/trunk@85976 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'os/bs2000')
-rw-r--r--os/bs2000/bs2login.c10
-rw-r--r--os/bs2000/ebcdic.c10
-rw-r--r--os/bs2000/os.c2
3 files changed, 11 insertions, 11 deletions
diff --git a/os/bs2000/bs2login.c b/os/bs2000/bs2login.c
index 38ef902747..8edad89ef2 100644
--- a/os/bs2000/bs2login.c
+++ b/os/bs2000/bs2login.c
@@ -169,11 +169,11 @@ static bs2_ForkType os_forktype(void)
/* This routine is called by http_core for the BS2000Account directive */
/* It stores the account name for later use */
-const char *os_set_account(ap_pool_t *p, const char *account)
+const char *os_set_account(apr_pool_t *p, const char *account)
{
char account_temp[ACCT_LEN+1];
- ap_cpystrn(account_temp, account, sizeof account_temp);
+ apr_cpystrn(account_temp, account, sizeof account_temp);
/* Make account all upper case */
ap_str_toupper(account_temp);
@@ -181,7 +181,7 @@ const char *os_set_account(ap_pool_t *p, const char *account)
/* Pad to length 8 */
ap_pad(account_temp, sizeof account_temp, ' ');
- bs2000_account = ap_pstrdup(p, account_temp);
+ bs2000_account = apr_pstrdup(p, account_temp);
return NULL;
}
@@ -226,7 +226,7 @@ int os_init_job_environment(server_rec *server, const char *user_name, int one_p
exit(APEXIT_CHILDFATAL);
}
- ap_cpystrn(username, user_name, sizeof username);
+ apr_cpystrn(username, user_name, sizeof username);
/* Make user name all upper case */
ap_str_toupper(username);
@@ -269,7 +269,7 @@ pid_t os_fork(const char *user)
break;
case bs2_UFORK:
- ap_cpystrn(username, user, sizeof username);
+ apr_cpystrn(username, user, sizeof username);
/* Make user name all upper case - for some versions of ufork() */
ap_str_toupper(username);
diff --git a/os/bs2000/os.c b/os/bs2000/os.c
index 591d96414c..2ad3a49669 100644
--- a/os/bs2000/os.c
+++ b/os/bs2000/os.c
@@ -89,7 +89,7 @@ int ap_checkconv(struct request_rec *r)
strncasecmp(type, "message/", 8) == 0)) {
if (strncasecmp(type, ASCIITEXT_MAGIC_TYPE_PREFIX,
sizeof(ASCIITEXT_MAGIC_TYPE_PREFIX)-1) == 0)
- r->content_type = ap_pstrcat(r->pool, "text/",
+ r->content_type = apr_pstrcat(r->pool, "text/",
type+sizeof(ASCIITEXT_MAGIC_TYPE_PREFIX)-1,
NULL);
else
diff --git a/os/bs2000/ebcdic.c b/os/bs2000/ebcdic.c
index 82bb52a60b..70b6f15014 100644
--- a/os/bs2000/ebcdic.c
+++ b/os/bs2000/ebcdic.c
@@ -67,7 +67,7 @@ Within the POSIX subsystem, the same character set was chosen as in
"native BS2000", namely EBCDIC.
EBCDIC Table. (Yes, in EBCDIC, the letters 'a'..'z' are not contiguous!)
-This ap_table_t is bijective, i.e. there are no ambigous or duplicate characters
+This apr_table_t is bijective, i.e. there are no ambigous or duplicate characters
00 00 01 02 03 85 09 86 7f 87 8d 8e 0b 0c 0d 0e 0f *................*
10 10 11 12 13 8f 0a 08 97 18 19 9c 9d 1c 1d 1e 1f *................*
20 80 81 82 83 84 92 17 1b 88 89 8a 8b 8c 05 06 07 *................*
@@ -122,17 +122,17 @@ const unsigned char os_toascii_strictly[256] = {
0x38, 0x39, 0xb3, 0x7b, 0xdc, 0x7d, 0xda, 0x7e /*0123456789.{.}.~*/
};
/* This ap_table_t is (almost) identical to the previous one. The only difference
* is the fact that it maps every EBCDIC *except 0x0A* to its ASCII
* equivalent. The reason for this ap_table_t is simple: Throughout the
* server, protocol strings are used in the form
* "Content-Type: text/plain\015\012". Now all the characters in the string
* are stored as EBCDIC, only the semantics of \012 is completely
* different from LF (look it up in the ap_table_t above). \015 happens to be
* mapped to \015 anyway, so there's no special case for it.
*
* In THIS table, EBCDIC-\012 is mapped to ASCII-\012.
* This ap_table_t is therefore used wherever an EBCDIC to ASCII conversion is
* needed in the server.
*/
/* ebcdic-to-ascii with \012 mapped to ASCII-\n */
@@ -122,17 +122,17 @@ const unsigned char os_toascii_strictly[256] = {
0x38, 0x39, 0xb3, 0x7b, 0xdc, 0x7d, 0xda, 0x7e /*0123456789.{.}.~*/
};
-/* This ap_table_t is (almost) identical to the previous one. The only difference
+/* This apr_table_t is (almost) identical to the previous one. The only difference
* is the fact that it maps every EBCDIC *except 0x0A* to its ASCII
@@ -122,17 +122,17 @@ const unsigned char os_toascii_strictly[256] = {
* is the fact that it maps every EBCDIC *except 0x0A* to its ASCII
- * equivalent. The reason for this ap_table_t is simple: Throughout the
+ * equivalent. The reason for this apr_table_t is simple: Throughout the
* server, protocol strings are used in the form
* "Content-Type: text/plain\015\012". Now all the characters in the string
@@ -122,17 +122,17 @@ const unsigned char os_toascii_strictly[256] = {
* "Content-Type: text/plain\015\012". Now all the characters in the string
* are stored as EBCDIC, only the semantics of \012 is completely
- * different from LF (look it up in the ap_table_t above). \015 happens to be
+ * different from LF (look it up in the apr_table_t above). \015 happens to be
* mapped to \015 anyway, so there's no special case for it.
*
@@ -122,17 +122,17 @@ const unsigned char os_toascii_strictly[256] = {
*
* In THIS table, EBCDIC-\012 is mapped to ASCII-\012.
- * This ap_table_t is therefore used wherever an EBCDIC to ASCII conversion is
+ * This apr_table_t is therefore used wherever an EBCDIC to ASCII conversion is
* needed in the server.
*/